==========
Credits
==========

Development Lead
-----------------
* Thalia Valle
* Marcelo Amorim
* Henrique Baggio
  - Email: <thaliasaxo@gmail.com>
  - Email: <jrmarcelo2011@gmail.com>
  - Email: <iquebaggio@gmail.com>

Contributors
-----------------
None yet. Why not be the first?
